@@ -1,4 +1,4 @@
-import sys, pyautogui, logging, time
+import os, sys, pyautogui, logging, time
 
 def printReceipt():
     # Prevent PIL from adding to log
@@ -8,7 +8,8 @@ def printReceipt():
     logging.basicConfig(level=logging.DEBUG, filename="print.log", filemode="w")
 
     # Get coords for and click the ticket dropdown
-    coords = pyautogui.locateCenterOnScreen('imgs/img.png')
+    imagePath = os.path.join(os.path.dirname(__file__), "imgs/img.png")
+    coords = pyautogui.locateCenterOnScreen(imagePath)
 
     # Quit program execution when coords = None
     if coords is None:
@@ -25,7 +26,8 @@ def printReceipt():
     time.sleep(0.5)
 
     # Look for get routing prompt
-    promptCoords = pyautogui.locateCenterOnScreen('imgs/prompt.png')
+    imagePath = os.path.join(os.path.dirname(__file__), "imgs/prompt.png")
+    promptCoords = pyautogui.locateCenterOnScreen(imagePath)
     if promptCoords is not None:
         # We have found the prompt, click the ok button.
         xCoord = promptCoords.x - 80
